@@ -18,8 +18,8 @@ class EMBLFileParser : public FileParser
         /* Functions */
         EMBLFileParser(string filePath);
         ~EMBLFileParser();
-        virtual Sequence getSeq(int seqNum);
-        virtual vector<Sequence> getSeqRange(int firstSeq, int num);
+        virtual Sequence getSeq(int seqNum, string *offendingSeq=NULL);
+        virtual vector<Sequence> getSeqRange(int firstSeq, int num, string *offendingSeq=NULL);
         virtual int countSeqs();
         virtual void getSecStructure(vector<char>& gapPenaltyMask, 
                 vector<char>& secStructMask,
